@@ -7,8 +7,13 @@ import functools
 import scipy as sp
 
 from PyQt4.QtGui import QApplication
+from PyQt4 import QtCore
+from PyQt4.QtGui import QProgressDialog
 from guiqwt.builder import make
 
+from ..progress_indicator import (ProgressIndicator,
+                                  CancelException)
+
 
 class _MarkerName:
     """ Helper class to create marker name functions for different strings.
@@ -219,4 +224,52 @@ def make_window_legend(win, objects, show_option=None):
         else:
             name = 'No identifier'
         legend.append((get_object_color(u), name))
-    win.add_color_legend(legend, show_option)
\ No newline at end of file
+    win.add_color_legend(legend, show_option)
+
+
+class ProgressIndicatorDialog(ProgressIndicator, QProgressDialog):
+    """ This class implements
+    :class:`spykeutils.progress_indicator.ProgressIndicator` as a
+    ``QProgressDialog``. It can be used to indicate progress in a graphical
+    user interface. Qt needs to be initialized in order to use it.
+    """
+    def __init__(self, parent, title='Processing...'):
+        QProgressDialog.__init__(self, parent)
+        self.setWindowTitle(title)
+        self.setMinimumWidth(500)
+        self.setAutoReset(False)
+
+    def set_ticks(self, ticks):
+        self.setMaximum(ticks)
+        if self.isVisible():
+            self.setValue(0)
+
+    def begin(self, title='Processing...'):
+        self.setWindowTitle(title)
+        self.setLabelText('')
+        self.setValue(0)
+
+        if not self.isVisible():
+            self.reset()
+            self.open()
+
+        QtCore.QCoreApplication.instance().processEvents()
+
+    def step(self, num_steps=1):
+        if not self.isVisible():
+            return
+
+        self.setValue(self.value() + num_steps)
+        QtCore.QCoreApplication.instance().processEvents()
+        if self.wasCanceled():
+            self.done()
+            raise CancelException()
+
+        super(ProgressIndicatorDialog, self).step()
+
+    def set_status(self, status):
+        self.setLabelText(status)
+        QtCore.QCoreApplication.instance().processEvents()
+
+    def done(self):
+        self.reset()
